%global pypi_name yaql

%if 0%{?fedora}  || 0%{?rhel} > 7
%global with_python3 1
%{!?python3_shortver: %global python3_shortver %(%{__python3} -c 'import sys; print(str(sys.version_info.major) + "." + str(sys.version_info.minor))')}
%endif

%bcond_with docs

Name:           python-%{pypi_name}
Version:        1.1.3
Release:        8%{?dist}.1
Summary:        Yet Another Query Language

License:        ASL 2.0
URL:            https://pypi.python.org/pypi/%{pypi_name}
Source0:        https://tarballs.openstack.org/%{pypi_name}/%{pypi_name}-%{version}.tar.gz

BuildArch:      noarch

%description
YAQL library has a out of the box large set of commonly used functions.

# Python3 package
%if 0%{?with_python3}
%package -n     python3-%{pypi_name}
Summary:        YAQL library has a out of the box large set of commonly used functions.
%{?python_provide:%python_provide python3-%{pypi_name}}

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-tools
BuildRequires:  python3-pbr
%if %{with docs}
BuildRequires:  python3-sphinx
BuildRequires:  python3-oslo-sphinx
%endif
Requires:       python3-six
Requires:       python3-pbr
Requires:       python3-babel
Requires:       python3-ply
Requires:       python3-dateutil

%description -n python3-%{pypi_name}
YAQL library has a out of the box large set of commonly used functions.
%endif

%if %{with docs}
# Documentation package
%package -n python-%{pypi_name}-doc
Summary:        Documentation for YAQL library

%description -n python-%{pypi_name}-doc
Documentation for YAQL library
%endif

%prep
%autosetup -n %{pypi_name}-%{version}
# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info
# Let RPM handle the dependencies
rm -f test-requirements.txt requirements.txt

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
2to3 --write --nobackups %{py3dir}
%endif

%build
%if 0%{?with_python3}
pushd %{py3dir}
LANG=en_US.UTF-8 %{__python3} setup.py build
popd
%endif
%if %{with docs}
# generate html docs 
sphinx-build doc/source html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%if 0%{?with_python3}
pushd %{py3dir}
LANG=en_US.UTF-8 %{__python3} setup.py install --skip-build --root %{buildroot}
mv %{buildroot}/%{_bindir}/%{pypi_name} %{buildroot}/%{_bindir}/python3-%{pypi_name}
popd
# rename binaries, make compat symlinks
pushd %{buildroot}%{_bindir}
for i in %{pypi_name}-{3,%{?python3_shortver}}; do
    ln -sf  python3-%{pypi_name} $i
done
%endif
popd

# Delete tests
rm -fr %{buildroot}%{python3_sitelib}/tests

# Files for python3
%if 0%{?with_python3}
%files -n python3-%{pypi_name} 
%license LICENSE
%doc doc/source/readme.rst README.rst
%{_bindir}/python3-%{pypi_name}
%{_bindir}/%{pypi_name}-3*
%{python3_sitelib}/%{pypi_name}
%{python3_sitelib}/%{pypi_name}-%{version}-py?.?.egg-info
%endif

%if %{with docs}
%files -n python-%{pypi_name}-doc
%doc html
%license LICENSE
%endif

%changelog
* Tue Dec 22 2020 CPaaS User <cpaas-ops@redhat.com> - 1.1.3-8.1
- Bump release

* Mon Oct 19 2020 Vath Sok <vsok@redhat.com> - 1.1.3-8
- Bump release number

* Mon Oct 19 2020 Vath Sok <vsok@redhat.com> - 1.1.3-7
- Bump release number

* Wed Oct 14 2020 Vath Sok <vsok@redhat.com> - 1.1.3-6
- rebuilt

* Tue Oct 13 2020 Vath Sok <vsok@redhat.com> - 1.1.3-5
- rebuilt

* Tue Oct 13 2020 Vath Sok <vsok@redhat.com> - 1.1.3-4
- rebuilt

* Thu Jan 17 2019 Shreshtha Joshi <shrjoshi@redhat.com> - 1.1.3-3
- RHEL8-isms

* Wed Feb 14 2018 Yatin Karel <ykarel@redhat.com> - 1.1.3-2
- Fix python-ply Requires for rhel

* Fri Feb 09 2018 Alfredo Moralejo <amoralej@redhat.com> - 1.1.3-1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1.1.0-4
- Rebuild for Python 3.6

* Mon Aug 22 2016 Haïkel Guémar <hguemar@fedoraproject.org> - 1.1.0-3
- Fix Requires in python2-yaql

* Fri Apr  8 2016 Haïkel Guémar <hguemar@fedoraproject.org> - 1.1.0-2
- Fix RHBZ#1282081

* Fri Apr  8 2016 Haïkel Guémar <hguemar@fedoraproject.org> - 1.1.0-1
- Upstream 1.1.0

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 18 2015 Marcos Fermin Lobo <marcos.fermin.lobo@cern.ch> 1.0.2-1.el7
- Update to 1.0.2

* Thu Nov 12 2015 Kalev Lember <klember@redhat.com> - 0.2.7-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Wed Aug 26 2015 Marcos Fermin Lobo <marcos.fermin.lobo@cern.ch> 0.2.7-1
- First RPM for FC23
